@@ -2,15 +2,21 @@
 # SPDX-License-Identifier: MIT
 
 import collections
+import copy
 import re
 from abc import ABC
 from typing import Any, Dict, List, Optional, SupportsIndex, Union, cast, overload
 
+from specfile.formatter import formatted
 from specfile.macro_options import MacroOptions
 from specfile.sections import Section
 from specfile.utils import split_conditional_macro_expansion
 
 
+def valid_prep_macro(name: str) -> bool:
+    return name in ("setup", "autosetup", "autopatch") or name.startswith("patch")
+
+
 class PrepMacro(ABC):
     """
     Class that represents a %prep macro.
@@ -56,15 +62,26 @@ class PrepMacro(ABC):
             preceding_lines.copy() if preceding_lines is not None else []
         )
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, PrepMacro):
+            return NotImplemented
+        return (
+            self.name == other.name
+            and self.options == other.options
+            and self._delimiter == other._delimiter
+            and self._prefix == other._prefix
+            and self._suffix == other._suffix
+            and self._preceding_lines == other._preceding_lines
+        )
+
+    @formatted
     def __repr__(self) -> str:
-        options = repr(self.options)
-        preceding_lines = repr(self._preceding_lines)
         # determine class name dynamically so that inherited classes
         # don't have to reimplement __repr__()
         return (
-            f"{self.__class__.__name__}('{self.name}', {options}, "
-            f"'{self._delimiter}', '{self._prefix}', '{self._suffix}', "
-            f"{preceding_lines})"
+            f"{self.__class__.__name__}({self.name!r}, {self.options!r}, "
+            f"{self._delimiter!r}, {self._prefix!r}, {self._suffix!r}, "
+            f"{self._preceding_lines!r})"
         )
 
     def get_raw_data(self) -> List[str]:
@@ -159,10 +176,9 @@ class PrepMacros(collections.UserList):
             self.data = data.copy()
         self._remainder = remainder.copy() if remainder is not None else []
 
+    @formatted
     def __repr__(self) -> str:
-        data = repr(self.data)
-        remainder = repr(self._remainder)
-        return f"PrepMacros({data}, {remainder})"
+        return f"PrepMacros({self.data!r}, {self._remainder!r})"
 
     def __contains__(self, item: object) -> bool:
         if isinstance(item, type):
@@ -204,7 +220,7 @@ class PrepMacros(collections.UserList):
             delete(i)
 
     def __getattr__(self, name: str) -> PrepMacro:
-        if not self.valid_prep_macro(name):
+        if not valid_prep_macro(name):
             return super().__getattribute__(name)
         try:
             return self.data[self.find(f"%{name}")]
@@ -212,19 +228,15 @@ class PrepMacros(collections.UserList):
             raise AttributeError(name)
 
     def __delattr__(self, name: str) -> None:
-        if not self.valid_prep_macro(name):
+        if not valid_prep_macro(name):
             return super().__delattr__(name)
         try:
             self.__delitem__(self.find(f"%{name}"))
         except ValueError:
             raise AttributeError(name)
 
-    @staticmethod
-    def valid_prep_macro(name: str) -> bool:
-        return name in ("setup", "autosetup", "autopatch") or name.startswith("patch")
-
     def copy(self) -> "PrepMacros":
-        return PrepMacros(self.data, self._remainder)
+        return copy.copy(self)
 
     def find(self, name: str) -> int:
         for i, macro in enumerate(self.data):
@@ -251,20 +263,25 @@ class Prep(collections.abc.Container):
     def __init__(self, macros: PrepMacros) -> None:
         self.macros = macros.copy()
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, Prep):
+            return NotImplemented
+        return self.macros == other.macros
+
+    @formatted
     def __repr__(self) -> str:
-        macros = repr(self.macros)
-        return f"Prep({macros})"
+        return f"Prep({self.macros!r})"
 
     def __contains__(self, item: object) -> bool:
         return item in self.macros
 
     def __getattr__(self, name: str) -> PrepMacro:
-        if not self.macros.valid_prep_macro(name):
+        if not valid_prep_macro(name):
             return super().__getattribute__(name)
         return getattr(self.macros, name)
 
     def __delattr__(self, name: str) -> None:
-        if not self.macros.valid_prep_macro(name):
+        if not valid_prep_macro(name):
             return super().__delattr__(name)
         return delattr(self.macros, name)
 
