@@ -14,6 +14,7 @@ import rpm
 from specfile.changelog import Changelog, ChangelogEntry
 from specfile.context_management import ContextManager
 from specfile.exceptions import SourceNumberException, SpecfileException
+from specfile.formatter import formatted
 from specfile.macro_definitions import MacroDefinition, MacroDefinitions
 from specfile.macros import Macro, Macros
 from specfile.prep import Prep
@@ -30,14 +31,7 @@ class Specfile:
     Class that represents a spec file.
 
     Attributes:
-        path: Path to the spec file.
-        sourcedir: Path to sources and patches.
         autosave: Whether to automatically save any changes made.
-        macros: List of extra macro definitions.
-        force_parse: Whether to attempt to parse the spec file even if one or more
-          sources required to be present at parsing time are not available.
-          Such sources include sources referenced from shell expansions
-          in tag values and sources included using the %include directive.
     """
 
     def __init__(
@@ -48,21 +42,47 @@ class Specfile:
         macros: Optional[List[Tuple[str, str]]] = None,
         force_parse: bool = False,
     ) -> None:
-        self.path = Path(path)
+        """
+        Constructs a `Specfile` object.
+
+        Args:
+            path: Path to the spec file.
+            sourcedir: Path to sources and patches.
+            autosave: Whether to automatically save any changes made.
+            macros: List of extra macro definitions.
+            force_parse: Whether to attempt to parse the spec file even if one or more
+              sources required to be present at parsing time are not available.
+              Such sources include sources referenced from shell expansions
+              in tag values and sources included using the %include directive.
+
+        Returns:
+            Constructed instance of `Specfile` class.
+        """
         self.autosave = autosave
+        self._path = Path(path)
         self._lines = self.path.read_text().splitlines()
         self._parser = SpecParser(
             Path(sourcedir or self.path.parent), macros, force_parse
         )
+        # parse here to fail early on parsing errors
         self._parser.parse(str(self))
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, Specfile):
+            return NotImplemented
+        return (
+            self.autosave == other.autosave
+            and self._path == other._path
+            and self._lines == other._lines
+            and self._parser == other._parser
+        )
+
+    @formatted
     def __repr__(self) -> str:
-        path = repr(self.path)
-        sourcedir = repr(self._parser.sourcedir)
-        autosave = repr(self.autosave)
-        macros = repr(self._parser.macros)
-        force_parse = repr(self._parser.force_parse)
-        return f"Specfile({path}, {sourcedir}, {autosave}, {macros}, {force_parse})"
+        return (
+            f"Specfile({self.path!r}, {self._parser.sourcedir!r}, {self.autosave!r}, "
+            f"{self._parser.macros!r}, {self._parser.force_parse!r})"
+        )
 
     def __str__(self) -> str:
         return "\n".join(self._lines) + "\n"
@@ -78,11 +98,24 @@ class Specfile:
     ) -> None:
         self.save()
 
+    @property
+    def path(self) -> Path:
+        """Path to the spec file."""
+        return self._path
+
+    @path.setter
+    def path(self, value: Union[Path, str]) -> None:
+        self._path = Path(value)
+
     @property
     def sourcedir(self) -> Path:
         """Path to sources and patches."""
         return self._parser.sourcedir
 
+    @sourcedir.setter
+    def sourcedir(self, value: Union[Path, str]) -> None:
+        self._parser.sourcedir = Path(value)
+
     @property
     def macros(self) -> List[Tuple[str, str]]:
         """List of extra macro definitions."""
@@ -96,6 +129,10 @@ class Specfile:
         """
         return self._parser.force_parse
 
+    @force_parse.setter
+    def force_parse(self, value: bool) -> None:
+        self._parser.force_parse = value
+
     @property
     def tainted(self) -> bool:
         """
@@ -103,17 +140,18 @@ class Specfile:
         sources required to be present at parsing time were not available
         and were replaced with dummy files.
         """
+        self._parser.parse(str(self))
         return self._parser.tainted
 
     @property
     def rpm_spec(self) -> rpm.spec:
         """Underlying `rpm.spec` instance."""
+        self._parser.parse(str(self))
         return self._parser.spec
 
     def reload(self) -> None:
         """Reload the spec file content."""
         self._lines = self.path.read_text().splitlines()
-        self._parser.parse(str(self))
 
     def save(self) -> None:
         """Save the spec file content."""
@@ -159,7 +197,6 @@ class Specfile:
         try:
             yield self._lines
         finally:
-            self._parser.parse(str(self))
             if self.autosave:
                 self.save()
 
@@ -194,11 +231,9 @@ class Specfile:
                 lines[:] = sections.get_raw_data()
 
     @property
-    def parsed_sections(self) -> Optional[Sections]:
+    def parsed_sections(self) -> Sections:
         """Parsed spec file sections."""
-        if not self._parser.spec:
-            return None
-        return Sections.parse(self._parser.spec.parsed.splitlines())
+        return Sections.parse(self.rpm_spec.parsed.splitlines())
 
     @ContextManager
     def tags(
@@ -217,7 +252,7 @@ class Specfile:
         with self.sections() as sections:
             if isinstance(section, Section):
                 raw_section = section
-                parsed_section = getattr(self.parsed_sections, section.name, None)
+                parsed_section = getattr(self.parsed_sections, section.id, None)
             else:
                 raw_section = getattr(sections, section)
                 parsed_section = getattr(self.parsed_sections, section, None)
@@ -289,7 +324,7 @@ class Specfile:
             sourcelists = [
                 (s, Sourcelist.parse(s, context=self))
                 for s in sections
-                if s.name == "sourcelist"
+                if s.id == "sourcelist"
             ]
             try:
                 yield Sources(
@@ -326,7 +361,7 @@ class Specfile:
             patchlists = [
                 (s, Sourcelist.parse(s, context=self))
                 for s in sections
-                if s.name == "patchlist"
+                if s.id == "patchlist"
             ]
             try:
                 yield Patches(
@@ -477,6 +512,9 @@ class Specfile:
     license = _tag("license", "License as stored in the spec file.")
     expanded_license = _expanded_tag("license", "License with macros expanded.")
 
+    epoch = _tag("epoch", "Epoch as stored in the spec file.")
+    expanded_epoch = _expanded_tag("epoch", "Epoch with macros expanded.")
+
     url = _tag("url", "URL as stored in the spec file.")
     expanded_url = _expanded_tag("url", "URL with macros expanded.")
 
