@@ -2,11 +2,13 @@
 # SPDX-License-Identifier: MIT
 
 import collections
+import copy
 import itertools
 import re
 from typing import Any, Iterable, List, Optional, SupportsIndex, Union, cast, overload
 
 from specfile.constants import TAG_NAMES, TAGS_WITH_ARG
+from specfile.formatter import formatted
 from specfile.sections import Section
 from specfile.utils import split_conditional_macro_expansion
 
@@ -34,11 +36,17 @@ class Comment:
         self.text = text
         self.prefix = prefix
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, Comment):
+            return NotImplemented
+        return self.text == other.text and self.prefix == other.prefix
+
     def __str__(self) -> str:
         return f"{self.prefix}{self.text}"
 
+    @formatted
     def __repr__(self) -> str:
-        return f"Comment('{self.text}', '{self.prefix}')"
+        return f"Comment({self.text!r}, {self.prefix!r})"
 
 
 class Comments(collections.UserList):
@@ -72,10 +80,9 @@ class Comments(collections.UserList):
             preceding_lines.copy() if preceding_lines is not None else []
         )
 
+    @formatted
     def __repr__(self) -> str:
-        data = repr(self.data)
-        preceding_lines = repr(self._preceding_lines)
-        return f"Comments({data}, {preceding_lines})"
+        return f"Comments({self.data!r}, {self._preceding_lines!r})"
 
     def __contains__(self, item: object) -> bool:
         if isinstance(item, str):
@@ -125,7 +132,7 @@ class Comments(collections.UserList):
                 self.data[i] = item
 
     def copy(self) -> "Comments":
-        return Comments(self.data, self._preceding_lines)
+        return copy.copy(self)
 
     def append(self, item: Union[Comment, str]) -> None:
         if isinstance(item, str):
@@ -237,12 +244,11 @@ class Tag:
             and self._suffix == other._suffix
         )
 
+    @formatted
     def __repr__(self) -> str:
-        comments = repr(self.comments)
-        expanded_value = repr(self._expanded_value)
         return (
-            f"Tag('{self.name}', '{self.value}', {expanded_value}, "
-            f"'{self._separator}', {comments}, '{self._prefix}', '{self._suffix}')"
+            f"Tag({self.name!r}, {self.value!r}, {self._expanded_value!r}, "
+            f"{self._separator!r}, {self.comments!r}, {self._prefix!r}, {self._suffix!r})"
         )
 
     @property
@@ -317,10 +323,9 @@ class Tags(collections.UserList):
             self.data = data.copy()
         self._remainder = remainder.copy() if remainder is not None else []
 
+    @formatted
     def __repr__(self) -> str:
-        data = repr(self.data)
-        remainder = repr(self._remainder)
-        return f"Tags({data}, {remainder})"
+        return f"Tags({self.data!r}, {self._remainder!r})"
 
     @overload
     def __getitem__(self, i: SupportsIndex) -> Tag:
@@ -404,7 +409,7 @@ class Tags(collections.UserList):
             raise AttributeError(name)
 
     def copy(self) -> "Tags":
-        return Tags(self.data, self._remainder)
+        return copy.copy(self)
 
     def find(self, name: str) -> int:
         for i, tag in enumerate(self.data):
