@@ -49,11 +49,11 @@ def test_parse():
         ]
     )
     assert sections[0][0] == "0"
-    assert sections[1].name == "prep"
+    assert sections[1].id == "prep"
     assert sections.prep == ["0", "1", "2", ""]
-    assert sections[2].name == "package x"
+    assert sections[2].id == "package x"
     assert not sections[2]
-    assert sections[-1].name == "changelog"
+    assert sections[-1].id == "changelog"
 
 
 def test_parse_case_insensitive():
@@ -61,9 +61,9 @@ def test_parse_case_insensitive():
         ["0", "", "%Prep", "0", "1", "2", "", "%pAckage x", "Requires: bar"]
     )
     assert sections[0][0] == "0"
-    assert sections[1].name == "Prep"
+    assert sections[1].id == "Prep"
     assert sections.prep == ["0", "1", "2", ""]
-    assert sections[2].name == "pAckage x"
+    assert sections[2].id == "pAckage x"
     assert sections[2] == ["Requires: bar"]
 
 
@@ -79,11 +79,30 @@ def test_parse_invalid_name():
         ]
     )
     assert len(sections) == 2  # including empty preamble
-    assert sections[1].name == "description"
+    assert sections[1].id == "description"
     assert sections.description[2] == "%description(fr)"
 
 
 def test_copy_sections():
-    sections = Sections([Section("package"), Section("package bar")])
-    sections_copy = copy.deepcopy(sections)
-    assert sections == sections_copy
+    sections = Sections([Section("package", ["Name: test", "Version: 0.1"])])
+    shallow_copy = copy.copy(sections)
+    assert shallow_copy == sections
+    assert shallow_copy is not sections
+    assert shallow_copy[0] is sections[0]
+    deep_copy = copy.deepcopy(sections)
+    assert deep_copy == sections
+    assert deep_copy is not sections
+    assert deep_copy[0] is not sections[0]
+
+
+@pytest.mark.parametrize(
+    "section, is_script",
+    [
+        ("package", False),
+        ("install", True),
+        ("PostUn", True),
+        ("SourceList", False),
+    ],
+)
+def test_is_script(section, is_script):
+    assert Section(section).is_script == is_script
